import { ScalarsMap, ConvertNameFn } from '../types';
import { GraphQLObjectType, GraphQLInterfaceType, GraphQLNonNull, GraphQLList } from 'graphql';
export declare type PrimitiveField = string;
export declare type PrimitiveAliasedFields = {
    alias: string;
    fieldName: string;
};
export declare type LinkField = {
    alias: string;
    name: string;
    type: string;
    selectionSet: string;
};
export declare type NameAndType = {
    name: string;
    type: string;
};
export declare type ProcessResult = null | Array<NameAndType | string>;
export declare type SelectionSetProcessorConfig = {
    namespacedImportName: string | null;
    convertName: ConvertNameFn<any>;
    enumPrefix: boolean | null;
    scalars: ScalarsMap;
    formatNamedField: (name: string) => string;
    wrapTypeWithModifiers: (baseType: string, type: GraphQLObjectType | GraphQLNonNull<GraphQLObjectType> | GraphQLList<GraphQLObjectType>) => string;
};
export declare class BaseSelectionSetProcessor<Config extends SelectionSetProcessorConfig> {
    config: Config;
    constructor(config: Config);
    buildFieldsIntoObject(allObjectsMerged: string[]): string;
    buildSelectionSetFromStrings(pieces: string[]): string;
    transformPrimitiveFields(schemaType: GraphQLObjectType | GraphQLInterfaceType, fields: PrimitiveField[]): ProcessResult;
    transformAliasesPrimitiveFields(schemaType: GraphQLObjectType | GraphQLInterfaceType, fields: PrimitiveAliasedFields[]): ProcessResult;
    transformLinkFields(fields: LinkField[]): ProcessResult;
    transformTypenameField(type: string, name: string): ProcessResult;
}
